.. _recipe_asr.setup.materials:

asr.setup.materials
===================


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.setup.materials`-recipe.
This recipe is comprised of a single step, namely:

  - :py:func:`asr.setup.materials.main`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.setup.materials

or as a python module

.. code-block:: console

   $ python -m asr.setup.materials

Detailed description
--------------------
Generate database with test systems.

Steps
-----


asr.setup.materials
^^^^^^^^^^^^^^^^^^^
.. autofunction:: asr.setup.materials.main
   